import { VcViewer } from './components/viewer/index.mjs';
import { VcCompass, VcZoomControl, VcPrint, VcMyLocation, VcStatusBar, VcDistanceLegend, VcNavigation, VcCompassSm, VcZoomControlSm, VcNavigationSm, VcOverviewMap, VcSelectionIndicator } from './components/controls/index.mjs';
import _Measurements from './components/measurements/index.mjs';
import _Drawings from './components/drawings/index.mjs';
import _ImageryLayer from './components/imagery-layer/index.mjs';
import { VcImageryProviderAmap, VcImageryProviderArcgis, VcImageryProviderBaidu, VcImageryProviderBing, VcImageryProviderGoogle, VcImageryProviderGrid, VcImageryProviderIon, VcImageryProviderMapbox, VcImageryProviderOsm, VcImageryProviderSingletile, VcImageryProviderSupermap, VcImageryProviderTencent, VcImageryProviderTianditu, VcImageryProviderTileCoordinates, VcImageryProviderTms, VcImageryProviderTiledcache, VcImageryProviderUrltemplate, VcImageryProviderWms, VcImageryProviderWmts, VcTerrainProviderCesium, VcTerrainProviderArcgis, VcTerrainProviderVrTheworld, VcTerrainProviderTianditu } from './components/providers/index.mjs';
import { VcDatasourceCustom, VcDatasourceCzml, VcDatasourceGeojson, VcDatasourceKml } from './components/datasources/index.mjs';
import _Entity from './components/entity/index.mjs';
import { VcGraphicsBillboard, VcGraphicsBox, VcGraphicsCorridor, VcGraphicsCylinder, VcGraphicsEllipse, VcGraphicsEllipsoid, VcGraphicsLabel, VcGraphicsModel, VcGraphicsPath, VcGraphicsPlane, VcGraphicsPoint, VcGraphicsPolygon, VcGraphicsPolyline, VcGraphicsPolylineVolume, VcGraphicsRectangle, VcGraphicsTileset, VcGraphicsWall } from './components/graphics/index.mjs';
import { VcPrimitiveClassification, VcPrimitiveGround, VcPrimitiveGroundPolyline, VcPrimitiveModel, VcPrimitive, VcPrimitiveTileset, VcPrimitiveOsmBuildings, VcPrimitiveTimeDynamicPointCloud, VcPrimitiveI3sDataProvider, VcPrimitiveVoxel, VcPrimitiveParticle, VcPrimitiveCluster } from './components/primitives/index.mjs';
import { VcCollectionBillboard, VcCollectionCloud, VcCollectionLabel, VcCollectionPoint, VcCollectionPolyline, VcCollectionPrimitive, VcBillboard, VcCumulusCloud, VcLabel, VcPoint, VcPolyline, VcPolygon } from './components/primitive-collections/index.mjs';
import _GeometryInstance from './components/geometry-instance/index.mjs';
import { VcGeometryBox, VcGeometryBoxOutline, VcGeometryCircle, VcGeometryCircleOutline, VcGeometryPolygonCoplanar, VcGeometryPolygonCoplanarOutline, VcGeometryCorridor, VcGeometryCorridorOutline, VcGeometryCylinder, VcGeometryCylinderOutline, VcGeometryEllipse, VcGeometryEllipseOutline, VcGeometryEllipsoid, VcGeometryEllipsoidOutline, VcGeometryFrustum, VcGeometryFrustumOutline, VcGeometryGroundPolyline, VcGeometryPlane, VcGeometryPlaneOutline, VcGeometryPolygon, VcGeometryPolygonOutline, VcGeometryPolyline, VcGeometryPolylineVolume, VcGeometryPolylineVolumeOutline, VcGeometryRectangle, VcGeometryRectangleOutline, VcGeometrySimplePolyline, VcGeometrySphere, VcGeometrySphereOutline, VcGeometryWall, VcGeometryWallOutline } from './components/geometries/index.mjs';
import { VcOverlayHtml, VcOverlayHeatmap, VcOverlayWind, VcOverlayDynamic, VcOverlayEcharts, VcOverlayTyphoon } from './components/overlays/index.mjs';
import { VcPostProcessStage, VcPostProcessStageScan, VcPostProcessStageCollection } from './components/post-processes/index.mjs';
import { VcBtn, VcIcon, VcTooltip, VcAjaxBar, VcSkeleton, VcSpinnerBall, VcSpinnerBars, VcSpinnerDots, VcSpinnerGears, VcSpinnerHourglass, VcSpinnerIos, VcSpinnerOrbit, VcSpinnerOval, VcSpinnerPuff, VcSpinnerRings, VcSpinnerTail, VcSpinner, VcFab, VcFabAction, VcSlider } from './components/ui/index.mjs';
import _ConfigProvider from './components/config-provider/index.mjs';
import { VcAnalysisFlood, VcAnalyses } from './components/analyses/index.mjs';

var Components = [
  VcViewer,
  VcCompass,
  VcZoomControl,
  VcPrint,
  VcMyLocation,
  VcStatusBar,
  VcDistanceLegend,
  VcNavigation,
  VcCompassSm,
  VcZoomControlSm,
  VcNavigationSm,
  VcOverviewMap,
  VcSelectionIndicator,
  _Measurements,
  _Drawings,
  _ImageryLayer,
  VcImageryProviderAmap,
  VcImageryProviderArcgis,
  VcImageryProviderBaidu,
  VcImageryProviderBing,
  VcImageryProviderGoogle,
  VcImageryProviderGrid,
  VcImageryProviderIon,
  VcImageryProviderMapbox,
  VcImageryProviderOsm,
  VcImageryProviderSingletile,
  VcImageryProviderSupermap,
  VcImageryProviderTencent,
  VcImageryProviderTianditu,
  VcImageryProviderTileCoordinates,
  VcImageryProviderTms,
  VcImageryProviderTiledcache,
  VcImageryProviderUrltemplate,
  VcImageryProviderWms,
  VcImageryProviderWmts,
  VcTerrainProviderCesium,
  VcTerrainProviderArcgis,
  VcTerrainProviderVrTheworld,
  VcTerrainProviderTianditu,
  VcDatasourceCustom,
  VcDatasourceCzml,
  VcDatasourceGeojson,
  VcDatasourceKml,
  _Entity,
  VcGraphicsBillboard,
  VcGraphicsBox,
  VcGraphicsCorridor,
  VcGraphicsCylinder,
  VcGraphicsEllipse,
  VcGraphicsEllipsoid,
  VcGraphicsLabel,
  VcGraphicsModel,
  VcGraphicsPath,
  VcGraphicsPlane,
  VcGraphicsPoint,
  VcGraphicsPolygon,
  VcGraphicsPolyline,
  VcGraphicsPolylineVolume,
  VcGraphicsRectangle,
  VcGraphicsTileset,
  VcGraphicsWall,
  VcPrimitiveClassification,
  VcPrimitiveGround,
  VcPrimitiveGroundPolyline,
  VcPrimitiveModel,
  VcPrimitive,
  VcPrimitiveTileset,
  VcPrimitiveOsmBuildings,
  VcPrimitiveTimeDynamicPointCloud,
  VcPrimitiveI3sDataProvider,
  VcPrimitiveVoxel,
  VcPrimitiveParticle,
  VcPrimitiveCluster,
  VcCollectionBillboard,
  VcCollectionCloud,
  VcCollectionLabel,
  VcCollectionPoint,
  VcCollectionPolyline,
  VcCollectionPrimitive,
  VcBillboard,
  VcCumulusCloud,
  VcLabel,
  VcPoint,
  VcPolyline,
  VcPolygon,
  _GeometryInstance,
  VcGeometryBox,
  VcGeometryBoxOutline,
  VcGeometryCircle,
  VcGeometryCircleOutline,
  VcGeometryPolygonCoplanar,
  VcGeometryPolygonCoplanarOutline,
  VcGeometryCorridor,
  VcGeometryCorridorOutline,
  VcGeometryCylinder,
  VcGeometryCylinderOutline,
  VcGeometryEllipse,
  VcGeometryEllipseOutline,
  VcGeometryEllipsoid,
  VcGeometryEllipsoidOutline,
  VcGeometryFrustum,
  VcGeometryFrustumOutline,
  VcGeometryGroundPolyline,
  VcGeometryPlane,
  VcGeometryPlaneOutline,
  VcGeometryPolygon,
  VcGeometryPolygonOutline,
  VcGeometryPolyline,
  VcGeometryPolylineVolume,
  VcGeometryPolylineVolumeOutline,
  VcGeometryRectangle,
  VcGeometryRectangleOutline,
  VcGeometrySimplePolyline,
  VcGeometrySphere,
  VcGeometrySphereOutline,
  VcGeometryWall,
  VcGeometryWallOutline,
  VcOverlayHtml,
  VcOverlayHeatmap,
  VcOverlayWind,
  VcOverlayDynamic,
  VcOverlayEcharts,
  VcOverlayTyphoon,
  VcPostProcessStage,
  VcPostProcessStageScan,
  VcPostProcessStageCollection,
  VcBtn,
  VcIcon,
  VcTooltip,
  VcAjaxBar,
  VcSkeleton,
  VcSpinnerBall,
  VcSpinnerBars,
  VcSpinnerDots,
  VcSpinnerGears,
  VcSpinnerHourglass,
  VcSpinnerIos,
  VcSpinnerOrbit,
  VcSpinnerOval,
  VcSpinnerPuff,
  VcSpinnerRings,
  VcSpinnerTail,
  VcSpinner,
  VcFab,
  VcFabAction,
  VcSlider,
  _ConfigProvider,
  VcAnalysisFlood,
  VcAnalyses
];

export { Components as default };
//# sourceMappingURL=component.mjs.map
